MIH's extra DataLad functionality
*********************************

This is a template for creating a `DataLad <http://datalad.org>`__ extension
that equips DataLad with additional functionality.


API
===

High-level API commands
-----------------------

.. currentmodule:: datalad.api
.. autosummary::
   :toctree: generated

   x_configuration
   x_snakemake


Command line reference
----------------------

.. toctree::
   :maxdepth: 1

   generated/man/datalad-x-configuration
   generated/man/datalad-x-snakemake


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
